<!DOCTYPE html>
<html class="no-js" <?php language_attributes(); ?> xmlns:fb="http://ogp.me/ns/fb#">
<head prefix="og: http://ogp.me/ns# object: http://ogp.me/ns/object#">
<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>
	<?php
		global $page, $paged;
		wp_title( '|', true, 'right' );
		bloginfo( 'name' );
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) )
			echo " | $site_description";
		if ( $paged >= 2 || $page >= 2 )
			echo ' | ' . sprintf( __( 'Page %s', 'ocmx' ), max( $paged, $page ) );
	?>
</title>
<!-- Setup OpenGraph support-->
<?php if(get_option("ocmx_open_graph") !="yes") {
	$default_thumb = get_option('ocmx_site_thumbnail');
	$fb_image = get_fbimage();
	if(is_home()) : ?>
		<meta property="og:title" content="<?php bloginfo('name'); ?>"/>
		<meta property="og:description" content="<?php bloginfo('description'); ?>"/>
		<meta property="og:url" content="<?php echo home_url(); ?>"/>
		<meta property="og:image" content="<?php if(isset($default_thumb) && $default_thumb !==""){echo $default_thumb; } else {echo $fb_image;}?>"/>
		<meta property="og:type" content="<?php echo "website";?>"/>
		<meta property="og:site_name" content="<?php bloginfo('name'); ?>"/>
	<?php else : ?>
		<meta property="og:title" content="<?php the_title(); ?>"/>
		<meta property="og:description" content="<?php echo strip_tags($post->post_excerpt); ?>"/>
		<meta property="og:url" content="<?php the_permalink(); ?>"/>
		<meta property="og:image" content="<?php if($fb_image ==""){echo $default_thumb;} else {echo $fb_image;} ?>"/>
		<meta property="og:type" content="<?php echo "article"; ?>"/>
		<meta property="og:site_name" content="<?php bloginfo('name'); ?>"/>
	<?php endif;
}

if(get_option("ocmx_custom_favicon") != "") : ?>
	<link href="<?php echo get_option("ocmx_custom_favicon"); ?>" rel="icon" type="image/png" />
<?php endif;

wp_head(); ?>

<link rel="alternate" type="application/rss+xml" title="<?php bloginfo('name'); ?> RSS Feed" href="<?php bloginfo('rss2_url'); ?>" />
<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />

<!--[if lt IE 9]>
	   <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/ie.css" media="screen" />
<![endif]-->

</head>

<body <?php body_class(""); ?>>
<?php if( ! is_attachment() ) {
	if( ( is_singular() || is_page() )  && has_post_thumbnail( $post->ID ) ) :
		$bgimage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '1980x500' );
		$bgimage = $bgimage[0];
	elseif( get_header_image() != "" ) :
		$bgimage = get_header_image();
	endif; ?>
	<!--Begin Site Header -->
	<div id="header-container" <?php if( isset( $bgimage ) ) : ?>style="background: url(<?php echo $bgimage; ?>) no-repeat center; background-size: cover;"<?php endif; ?> class="has-background">
		<div id="header-control-container" <?php if( '' != get_option( 'ocmx_header_gradient' ) ) { echo 'class="' . get_option( 'ocmx_header_gradient' ) . '"'; } ?>>
			<div id="header" class="clearfix">
				<!--Show the Logo -->
				<div class="logo">
					<h1>
						<a href="<?php echo home_url(); ?>">
							<?php if( get_option( "ocmx_custom_logo" ) ) : ?>
								<img src="<?php echo get_option( "ocmx_custom_logo" ); ?>" alt="<?php bloginfo('name'); ?>" />
							<?php else : ?>
								<?php  strip_tags( bloginfo( 'name' ) ); ?>
							<?php endif; ?>
						</a>
					</h1>
				</div>
				<!--Show the Nav Menu -->
				<div id="navigation-container" class="clearfix">
					<a href="#" id="menu-drop-button"></a>
					<?php if ( function_exists( "wp_nav_menu" ) ) :
						wp_nav_menu(array(
							'menu' => 'Picks Nav',
							'menu_id' => 'nav',
							'menu_class' => 'clearfix',
							'sort_column' 	=> 'menu_order',
							'theme_location' => 'primary',
							'container' => 'ul',
							'fallback_cb' => 'ocmx_fallback')
						);
					endif; ?>
				</div>
			</div>
		</div>

		<?php get_template_part( '/functions/header-title' ); ?>
	<!--End WordPress Header -->
	</div>
	<!--Begin Layout -->
	<div id="content-container" class="<?php if( get_option( "ocmx_home_page_layout" ) == "collage" && is_home() || ( is_page() && is_page_template( 'collage.php' ) ) ): ?>home-collage<?php else: ?>contained<?php endif; ?> clearfix <?php echo get_option( "ocmx_sidebar_layout" ); ?>">
<?php } // if !is_attachment() ?>
