<?php
class ocmx_thumbnail_widget extends WP_Widget {
	/** constructor */
	function __construct() {
			$widget_ops = array( 'classname' => 'ocmx_thumbnail_widget', 'description' => 'Home Page Widget - Display your albums from a post or album category in a beautiful automated grid layout.' );
			parent::__construct( 'ocmx_thumbnail_widget', '(Obox) Thumbnail Grid Widget', $widget_ops );
    }
   /** @see WP_Widget::widget */
	function widget($args, $instance) {
		extract( $args );
		// Turn $args array into variables.
		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ('title'=>'', 'title_link' => '', 'post_thumb' => 1);
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );

		// If there is a custom link or title set, use them
		if( isset( $title ) && $title != '' )
			$the_cat_title = $title;
		if( isset( $title_link ) && $title_link != '' )
			$catlink = $title_link;

		// Setup the post filter if it's defined
		if(isset($postfilter) && isset($instance[$postfilter]))
			$filterval = esc_attr($instance[$postfilter]);
		else
			$filterval = 0;

		if(isset($postfilter) && $postfilter != "" && $filterval != "0") :
			$args = array(
				"post_type" => $posttype,
				"posts_per_page" => $post_count,
				"tax_query" => array(
					array(
						"taxonomy" => $postfilter,
						"field" => "slug",
						"terms" => $filterval
					)
				)
			);
		else :
			$args = array(
				"post_type" => $posttype,
				"posts_per_page" => $post_count
			);
		endif;

		// Set the post order
		if(isset($post_order_by)) :
			$args['order'] = $post_order;
			$args['orderby'] = $post_order_by;
		endif;

		$loop = new WP_Query($args); ?>

		<li class="widget">
		<?php if(isset($title) && $title !="") : ?>
			<div class="title-block">
				<h3 class="post-title">
					<?php if(isset($title_link) && $title_link !="") : ?>
						<a href="<?php if(isset ($title_link)) {echo $title_link;} ?>"><?php echo $title; ?></a>
					<?php else : ?>
						<?php echo $title; ?>
					<?php endif; ?>
				</h3>
			</div>
		<?php endif;

		while ( $loop->have_posts() ) : $loop->the_post();

			get_template_part( 'functions/album-list' );

		endwhile;
		wp_reset_postdata(); // Rewind WP_Query()
		// Large layout ?>
	</li>
<?php
	}

	 /** @see WP_Widget::update */
	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {
	// Turn $instance array into variables
		$instance_defaults = array ('title' => '', 'title_link' => '', 'posttype' => 'album' , 'post_thumb' => 1, 'postfilter' => '0' , 'post_image' => true );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );
		// Setup the post filter if it's defined
		if(isset($postfilter) && isset($instance[$postfilter]))
			$filterval = esc_attr($instance[$postfilter]);

		$post_type_args = array("public" => true, "exclude_from_search" => false, "show_ui" => true);
		$post_types = get_post_types( $post_type_args, "objects"); ?>

		<p><?php _e('Click Save after each drop-down option to load the next filter.','ocmx'); ?></p>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Custom Title", "ocmx"); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if(isset($title)){ echo $title; }?>" /></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('title_link'); ?>"><?php _e('Custom Title Link', 'ocmx'); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title_link'); ?>" type="text" value="<?php if(isset($title_link)) echo $title_link; ?>" /></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('posttype'); ?>">Display</label>
			<select size="1" class="widefat" id="<?php echo $this->get_field_id("posttype"); ?>" name="<?php echo $this->get_field_name("posttype"); ?>">
				<option <?php if(isset($posttype) && $posttype == ""){echo "selected=\"selected\"";} ?> value="">--- Select a Content Type ---</option>
				<?php foreach($post_types as $post_type => $details) :
						if($post_type == "page" || $post_type == 'attachment')
								continue; ?>
					<option <?php if($posttype == $post_type){echo "selected=\"selected\"";} ?> value="<?php echo $post_type; ?>"><?php echo $details->labels->name; ?></option>
				<?php endforeach; ?>
			</select>
		</p>

		<?php if($posttype != "") :
			if($posttype != "page" && $posttype != "attachment") : ?>
				<?php $taxonomyargs = array('post_type' => $posttype, "public" => true, "exclude_from_search" => false, "show_ui" => true);
				$taxonomies = get_object_taxonomies($taxonomyargs,'objects');
				if(!empty($taxonomies)) : ?>
					<p>
						<label for="<?php echo $this->get_field_id('postfilter'); ?>">Filter by</label>
						<select size="1" class="widefat" id="<?php echo $this->get_field_id("postfilter"); ?>" name="<?php echo $this->get_field_name("postfilter"); ?>">
							<option <?php if(isset($postfilter) && $postfilter == ""){echo "selected=\"selected\"";} ?> value="">--- Select a Filter ---</option>
							<?php foreach($taxonomies as $taxonomy => $details) : ?>
								<option <?php if(isset($postfilter) && $postfilter == $taxonomy){echo "selected=\"selected\"";} ?> value="<?php echo $taxonomy; ?>"><?php echo $details->labels->name; ?></option>
							<?php $validtaxes[] = $taxonomy;
							endforeach; ?>
						</select>
					</p>
				<?php endif;
				if(isset($postfilter) != "" && ( ( is_array($validtaxes) && in_array($postfilter, $validtaxes) ) || !is_array($validtaxes) ) ) :
					$tax = get_taxonomy($postfilter);
					$terms = get_terms($postfilter, "orderby=name&hide_empty=0"); ?>
					<p><label for="<?php echo $this->get_field_id($postfilter); ?>"><?php if(isset($tax->labels->name)) echo $tax->labels->name; ?></label>
					   <select size="1" class="widefat" id="<?php echo $this->get_field_id($postfilter); ?>" name="<?php echo $this->get_field_name($postfilter); ?>">
							<option <?php if(isset($filterval) && $filterval == 0){echo "selected=\"selected\"";} ?> value="0">All</option>
							<?php foreach($terms as $term => $details) :?>
								<option  <?php if(isset($filterval) && $filterval == $details->slug){echo "selected=\"selected\"";} ?> value="<?php echo $details->slug; ?>"><?php echo $details->name; ?></option>
							<?php endforeach;?>
						</select>
					</p>
				<?php endif; ?>
			<?php endif; ?>
			 <p>
				 <label for="<?php echo $this->get_field_id('post_count'); ?>">Post Count</label>
					<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_count'); ?>" name="<?php echo $this->get_field_name('post_count'); ?>">
						<?php $i = 1;
						while($i < 11) :?>
							<option <?php if(isset($post_count) && $post_count == $i) : ?>selected="selected"<?php endif; ?> value="<?php echo $i; ?>"><?php echo $i; ?></option>
						<?php if($i < 1) :
								$i++;
							else:
								$i=($i+1);
							endif;
						endwhile; ?>
					</select>
			 </p>
			<?php  // Setup the order values
				$order_params = array("date" => "Post Date", "title" => "Post Title", "rand" => "Random",  "comment_count" => "Comment Count",  "menu_order" => "Manual Order"); ?>
			<p>
				<label for="<?php echo $this->get_field_id('post_order_by'); ?>"><?php _e("Order By", "ocmx"); ?></label>
				<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order_by'); ?>" name="<?php echo $this->get_field_name('post_order_by'); ?>">
				<?php foreach($order_params as $value => $label) :?>
					<option  <?php if(isset($post_order_by) && $post_order_by == $value){echo "selected=\"selected\"";} ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
				<?php endforeach;?>
				</select>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('post_order'); ?>"><?php _e("Order", "ocmx"); ?></label>
				<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order'); ?>" name="<?php echo $this->get_field_name('post_order'); ?>">
					<option <?php if(!isset($post_order) || isset($post_order) && $post_order == "DESC") : ?>selected="selected"<?php endif; ?> value="DESC"><?php _e("Descending", 'ocmx'); ?></option>
					<option <?php if(isset($post_order) && $post_order == "ASC") : ?>selected="selected"<?php endif; ?> value="ASC"><?php _e("Ascending", 'ocmx'); ?></option>
				</select>
			</p>
            <?php if($posttype !='album') { ?>
			  <p>
				<label for="<?php echo $this->get_field_id('show_dates'); ?>">
					<input type="checkbox" <?php if(isset($show_dates) && $show_dates == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('show_dates'); ?>" name="<?php echo $this->get_field_name('show_dates'); ?>">
					Show Dates
				</label>
			  </p>
			  <p>
				<label for="<?php echo $this->get_field_id('show_excerpts'); ?>">
					<input type="checkbox" <?php if(isset($show_excerpts) && $show_excerpts == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('show_excerpts'); ?>" name="<?php echo $this->get_field_name('show_excerpts'); ?>">
					Show Excerpts
				</label>
			  </p>
<?php }
		endif;
	} // form

}// class
add_action('widgets_init', create_function('', 'return register_widget("ocmx_thumbnail_widget");'));