<?php
class ocmx_large_thumbnail_widget extends WP_Widget {
	/** constructor */
	function __construct() {
			$widget_ops = array( 'classname' => 'ocmx_large_thumbnail_widget', 'description' => 'Home Page Widget - Display your albums from a post or album category in a large layout.' );
			parent::__construct( 'ocmx_large_thumbnail_widget', '(Obox) Large Image Widget', $widget_ops );
    }
   /** @see WP_Widget::widget */
	function widget($args, $instance) {
		extract( $args );
		// Turn $args array into variables.
		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ('title'=>'', 'title_link' => '', 'post_thumb' => 1);
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );

		// If there is a custom link or title set, use them
		if( isset( $title ) && $title != '' )
			$the_cat_title = $title;
		if( isset( $title_link ) && $title_link != '' )
			$catlink = $title_link;

		// Setup the post filter if it's defined
		if(isset($postfilter) && isset($instance[$postfilter]))
			$filterval = esc_attr($instance[$postfilter]);
		else
			$filterval = 0;

		if(isset($postfilter) && $postfilter != "" && $filterval != "0") :
			$args = array(
				"post_type" => $posttype,
				"posts_per_page" => $post_count,
				"tax_query" => array(
					array(
						"taxonomy" => $postfilter,
						"field" => "slug",
						"terms" => $filterval
					)
				)
			);
		else :
			$args = array(
				"post_type" => $posttype,
				"posts_per_page" => $post_count
			);
		endif;

		// Set the post order
		if(isset($post_order_by)) :
			$args['order'] = $post_order;
			$args['orderby'] = $post_order_by;
		endif;

		$loop = new WP_Query($args); ?>

		<li class="widget">
			<?php if(isset($title) && $title !="") : ?>
				<div class="title-block">
					<h3 class="post-title">
						<?php if(isset($title_link) && $title_link !="") : ?>
							<a href="<?php if(isset ($title_link)) {echo $title_link;} ?>"><?php echo $title; ?></a>
						<?php else : ?>
							<?php echo $title; ?>
						<?php endif; ?>
					</h3>
				</div>
			<?php endif;  ?>
		<ul class="photolist">
			<?php while ( $loop->have_posts() ) : $loop->the_post();
			global $post;

			// get the first attachment from the post
			$attachmentargs = array("post_type" => "attachment", "post_parent" => $post->ID, "numberposts" => "1", "orderby" => "menu_order", "order" => "ASC");
			$attachments = get_posts($attachmentargs); ?>

			<li class="photo-item clearfix">
				<?php // If we are using a video, make use of obox_media();
					if(obox_has_video($post->ID)) :
						if( isset( $post_image ) && $post_image == 'true' ) {
							$exclude_video = true;
						} else {
							$exclude_video = false;
						}
						$args  = array('postid' => $post->ID, 'width' => '1000', 'height' => '', 'hide_href' => true, 'imglink' => false, 'imgnocontainer' => true, 'resizer' => '1080auto', 'exclude_video' => $exclude_video);
						$image = get_obox_media($args);
						echo $image;
					elseif( !empty($attachments) ) :
						// Use the first image from our attachments array()
						$this_attachment = $attachments[0];
						$attachimage = wp_get_attachment_image_src($this_attachment->ID, '1080auto'); ?>
						<div class="post-photo">
							<a class="info" href="#"><?php _e('More Info','ocmx'); ?></a>
							<a class="photo" href="<?php the_permalink(); ?>">
								<img src="<?php echo $attachimage[0]; ?>" alt="<?php the_title($post->ID) ?>" />
							</a>
						</div>
						<div class="photo-meta">
							<ul>
								<li class="meta-type url">
									<h6><?php _e('Direct Link','ocmx'); ?></h6>
									<small><?php echo wp_get_shortlink( $post->ID ); ?></small>
								</li>
								<?php
								// Get the image EXIF data and Instagram meta, if it's available.
								$instagram_meta = get_post_meta($this_attachment->ID, '_instagram_meta', true);
								$exifdata = wp_get_attachment_metadata($this_attachment->ID);

								// This post has Instagram data, use that instead of the Exif
								if($instagram_meta != "") :
									if(get_option("ocmx_meta_tags") != "false") :
										$tags = $instagram_meta['tags'];
										if(!empty($tags)) : ?>
											<li class="meta-type category-list">
												<h6><?php _e('Tags','ocmx'); ?></h6>
												<?php foreach($tags as $tag) : ?>
													<a href=""><?php echo $tag; ?></a>
												<?php endforeach; ?>
											</li>
										<?php endif;
									endif; ?>
									<li class="meta-type exif-data">
										<h6><?php _e('Instagram Data','ocmx'); ?></h6>
										<ul>
											<li><span class="exif-type camera"><?php _e('Filter','ocmx'); ?></span> <?php echo $instagram_meta["filter"]; ?></li>
											<li><span class="exif-type focal"><?php _e('User','ocmx'); ?></span> <?php echo $instagram_meta["username"]; ?></li>
											<?php if($instagram_meta["location"] != "") : ?>
												<li><span class="exif-type shutter"><?php _e('Location','ocmx'); ?></span> <?php echo $instagram_meta["location"]; ?></li>
											<?php endif; ?>
										</ul>
									</li>
								<?php  // If there is no exif, use normal image meta
								else :
									// Use the tags from the post
									if(get_option("ocmx_meta_tags_album") != "false") :
										$tags = wp_get_object_terms($post->ID, 'album-tag');
										if(!empty($tags)) : ?>
											<li class="meta-type category-list">
												<h6><?php _e('Tags','ocmx'); ?></h6>
												<?php foreach($tags as $tax) : ?>
													<a href="<?php echo get_term_link($tax->slug, 'album-tag'); ?>">
														<?php echo $tax->name; ?>
													</a>
												<?php endforeach; ?>
											</li>
										<?php endif;
									endif;

									// Loop through the Exif data to see if we actually have anything to use
									$hasmeta = 0;
									foreach($exifdata["image_meta"] as $meta) :
										if($meta != 0)
											$hasmeta = 1;
									endforeach;

									// Display the Exif data
									if($hasmeta == 1 && isset($exifdata)) : ?>
										<li class="meta-type exif-data">
											<h6><?php _e('Exif Data','ocmx'); ?></h6>
											<ul>
												<?php if(!empty($exifdata["image_meta"]["camera"])) : ?>
													<li><span class="exif-type camera"><?php _e('Camera','ocmx'); ?></span> <?php echo $exifdata["image_meta"]["camera"]; ?></li>
												<?php endif; ?>
												<?php if(!empty($exifdata["image_meta"]["focal_length"])) : ?>
													<li><span class="exif-type focal"><?php _e('Focal Length','ocmx'); ?></span> <?php echo $exifdata["image_meta"]["focal_length"]; ?>mm</li>
												<?php endif; ?>
												<?php if(!empty($exifdata["image_meta"]["shutter_speed"])) : ?>
													<li><span class="exif-type shutter"><?php _e('Shutter Speed','ocmx'); ?></span> <?php echo $exifdata["image_meta"]["shutter_speed"]; ?> sec</li>
												<?php endif; ?>
												<?php if(!empty($exifdata["image_meta"]["aperture"])) : ?>
													<li><span class="exif-type aperature"><?php _e('Aperature','ocmx'); ?></span> f/<?php echo $exifdata["image_meta"]["aperture"]; ?></li>
												<?php endif; ?>
												<?php if(!empty($exifdata["image_meta"]["iso"])) : ?>
													<li><span class="exif-type iso-type"><?php _e('ISO','ocmx'); ?></span> <?php echo $exifdata["image_meta"]["iso"]; ?></li>
												<?php endif; ?>
											</ul>
										</li>
									<?php endif; ?>
								<?php endif; ?>
							</ul>
						</div>
					<?php endif; ?>

					<div class="photo-details clearfix">
						<?php // Check to see if we're allowed to show dates
						if(isset($show_dates) == "on") : ?>
							<h5 class="post-date"><?php the_time(get_option('date_format')); ?></h5>
						<?php endif; ?>
						<h3 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
						<?php // Excerpts on/off
						if(isset($show_excerpts) && $show_excerpts == "on") :
							// Check if we're using a real excerpt or the content
							if($post->post_excerpt != "") :
								$excerpttext = '<p>'.get_the_excerpt().'</p>';
							elseif( strpos( get_the_content() , 'more-link' ) ) :
								$excerpttext = get_the_content('');
							endif;

							// If the Excerpt exists, continue
							if( isset( $excerpttext ) ) :
								echo '<div class="copy">'.$excerpttext.'</div>';
							endif;
						endif; ?>
					</div>
				</li>
			<?php endwhile;
			wp_reset_postdata(); // Rewind WP_Query() ?>
		</ul>
	</li>
<?php
	}

	 /** @see WP_Widget::update */
	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {
	// Turn $instance array into variables
		$instance_defaults = array ('title' => '', 'title_link' => '', 'posttype' => 'album', 'post_thumb' => 1, 'postfilter' => '0');
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );
		// Setup the post filter if it's defined
		if(isset($postfilter) && isset($instance[$postfilter]))
			$filterval = esc_attr($instance[$postfilter]);

		$post_type_args = array("public" => true, "exclude_from_search" => false, "show_ui" => true);
		$post_types = get_post_types( $post_type_args, "objects"); ?>

		<p><?php _e('Click Save after each drop-down option to load the next filter.','ocmx'); ?></p>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Custom Title", "ocmx"); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if(isset($title)){ echo $title; }?>" /></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('title_link'); ?>"><?php _e('Custom Title Link', 'ocmx'); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title_link'); ?>" type="text" value="<?php if(isset($title_link)) echo $title_link; ?>" /></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('posttype'); ?>">Display</label>
			<select size="1" class="widefat" id="<?php echo $this->get_field_id("posttype"); ?>" name="<?php echo $this->get_field_name("posttype"); ?>">
				<option <?php if(isset($posttype) && $posttype == ""){echo "selected=\"selected\"";} ?> value="">--- Select a Content Type ---</option>
				<?php foreach($post_types as $post_type => $details) :
						if($post_type == "page")
								continue; ?>
					<option <?php if($posttype == $post_type){echo "selected=\"selected\"";} ?> value="<?php echo $post_type; ?>"><?php echo $details->labels->name; ?></option>
				<?php endforeach; ?>
			</select>
		</p>

		<?php if($posttype != "") :
			if($posttype != "page" && $posttype != "attachment") : ?>
				<?php $taxonomyargs = array('post_type' => $posttype, "public" => true, "exclude_from_search" => false, "show_ui" => true);
				$taxonomies = get_object_taxonomies($taxonomyargs,'objects');
				if(!empty($taxonomies)) : ?>
					<p>
						<label for="<?php echo $this->get_field_id('postfilter'); ?>">Filter by</label>
						<select size="1" class="widefat" id="<?php echo $this->get_field_id("postfilter"); ?>" name="<?php echo $this->get_field_name("postfilter"); ?>">
							<option <?php if(isset($postfilter) && $postfilter == ""){echo "selected=\"selected\"";} ?> value="">--- Select a Filter ---</option>
							<?php foreach($taxonomies as $taxonomy => $details) : ?>
								<option <?php if(isset($postfilter) && $postfilter == $taxonomy){echo "selected=\"selected\"";} ?> value="<?php echo $taxonomy; ?>"><?php echo $details->labels->name; ?></option>
							<?php $validtaxes[] = $taxonomy;
							endforeach; ?>
						</select>
					</p>
				<?php endif;
				if(isset($postfilter) != "" && ( ( is_array($validtaxes) && in_array($postfilter, $validtaxes) ) || !is_array($validtaxes) ) ) :
					$tax = get_taxonomy($postfilter);
					$terms = get_terms($postfilter, "orderby=name&hide_empty=0"); ?>
					<p><label for="<?php echo $this->get_field_id($postfilter); ?>"><?php if(isset($tax->labels->name)) echo $tax->labels->name; ?></label>
					   <select size="1" class="widefat" id="<?php echo $this->get_field_id($postfilter); ?>" name="<?php echo $this->get_field_name($postfilter); ?>">
							<option <?php if(isset($filterval) && $filterval == 0){echo "selected=\"selected\"";} ?> value="0">All</option>
							<?php foreach($terms as $term => $details) :?>
								<option  <?php if(isset($filterval) && $filterval == $details->slug){echo "selected=\"selected\"";} ?> value="<?php echo $details->slug; ?>"><?php echo $details->name; ?></option>
							<?php endforeach;?>
						</select>
					</p>
				<?php endif; ?>
			<?php endif; ?>
			 <p>
				 <label for="<?php echo $this->get_field_id('post_count'); ?>">Post Count</label>
					<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_count'); ?>" name="<?php echo $this->get_field_name('post_count'); ?>">
						<?php $i = 1;
						while($i < 20) :?>
							<option <?php if(isset($post_count) && $post_count == $i) : ?>selected="selected"<?php endif; ?> value="<?php echo $i; ?>"><?php echo $i; ?></option>
						<?php if($i < 1) :
								$i++;
							else:
								$i=($i+1);
							endif;
						endwhile; ?>
					</select>
			 </p>
			<?php  // Setup the order values
				$order_params = array("date" => "Post Date", "title" => "Post Title", "rand" => "Random",  "comment_count" => "Comment Count",  "menu_order" => "Manual Order"); ?>
			<p>
				<label for="<?php echo $this->get_field_id('post_order_by'); ?>"><?php _e("Order By", "ocmx"); ?></label>
				<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order_by'); ?>" name="<?php echo $this->get_field_name('post_order_by'); ?>">
				<?php foreach($order_params as $value => $label) :?>
					<option  <?php if(isset($post_order_by) && $post_order_by == $value){echo "selected=\"selected\"";} ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
				<?php endforeach;?>
				</select>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('post_order'); ?>"><?php _e("Order", "ocmx"); ?></label>
				<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order'); ?>" name="<?php echo $this->get_field_name('post_order'); ?>">
					<option <?php if(!isset($post_order) || isset($post_order) && $post_order == "DESC") : ?>selected="selected"<?php endif; ?> value="DESC"><?php _e("Descending", 'ocmx'); ?></option>
					<option <?php if(isset($post_order) && $post_order == "ASC") : ?>selected="selected"<?php endif; ?> value="ASC"><?php _e("Ascending", 'ocmx'); ?></option>
				</select>
			</p>
			<p>
				 <label for="<?php echo $this->get_field_id('post_image'); ?>">Thumbnail Preference</label>
				<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_image'); ?>" name="<?php echo $this->get_field_name('post_image'); ?>">
					<option <?php if($post_image == "true") : ?>selected="selected"<?php endif; ?> value="true">Post Feature Image</option>
					<option <?php if($post_image == "false") : ?>selected="selected"<?php endif; ?> value="false">Videos</option>
				</select>
				<em>Select whether or not to prioritize your posts' featured image or video.</em>
			</p>
			  <p>
				<label for="<?php echo $this->get_field_id('show_dates'); ?>">
					<input type="checkbox" <?php if(isset($show_dates) && $show_dates == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('show_dates'); ?>" name="<?php echo $this->get_field_name('show_dates'); ?>">
					Show Dates
				</label>
			  </p>
			  <p>
				<label for="<?php echo $this->get_field_id('show_excerpts'); ?>">
					<input type="checkbox" <?php if(isset($show_excerpts) && $show_excerpts == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('show_excerpts'); ?>" name="<?php echo $this->get_field_name('show_excerpts'); ?>">
					Show Excerpts
				</label>
			  </p>
<?php
		endif;
	} // form

}// class
add_action('widgets_init', create_function('', 'return register_widget("ocmx_large_thumbnail_widget");'));